% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/match_mi_general.R
\name{match_mi_general}
\alias{match_mi_general}
\title{General Matching Function for Multiple Imputation Data}
\usage{
match_mi_general(
  data,
  X,
  baseline_vars,
  estimand,
  method,
  subgroup = NULL,
  focal = NULL,
  sample_weights = NULL
)
}
\arguments{
\item{data}{A data frame or a 'mids' object containing the data for matching.}

\item{X}{A string naming the treatment or exposure variable within `data`.}

\item{baseline_vars}{A character vector naming the covariates to include in the
propensity score model.}

\item{estimand}{A string specifying the target estimand ('ATE', 'ATT', or 'ATC').}

\item{method}{The method for estimating propensity scores, per the
\code{\link[WeightIt]{WeightIt}} package's documentation.}

\item{subgroup}{(Optional) A string specifying a variable by which to subgroup
the data for within-group matching.}

\item{focal}{(Optional) Specifies the focal treatment group, useful for 'ATT' or
'ATC' estimands.}

\item{sample_weights}{(Optional) A string indicating the variable in `data`
representing sample weights.}

\item{stabilize}{Logical. Indicates whether to stabilize weights, defaulting to TRUE.}
}
\value{
A list of matched datasets for each subgroup level (if `subgroup` is used)
  or a single matched dataset. Each element is typically a data frame or an object
  reflecting the matched data structure, depending on the matching method applied.
}
\description{
This function facilitates propensity score matching on datasets, including those
generated through multiple imputation, to assess covariate balance across treatment
groups. It leverages the \code{\link[WeightIt]{WeightIt}} and
\code{\link[MatchThem]{MatchThem}} packages to calculate propensity scores and apply
matching techniques. Users are referred to these packages for detailed methodological
specifications and additional functionality.
}
\examples{
\dontrun{
# Assume `df` is a data frame with treatment, covariates, and sample weights
matched_data <- match_mi_general(data = df,
                                 X = "treatment_var",
                                 baseline_vars = c("covariate1", "covariate2"),
                                 estimand = "ATE",
                                 method = "nearest",
                                 stabilize = TRUE)
}

}
\references{
Detailed methodology and additional options can be found in:
- \code{\link[WeightIt]{WeightIt}} package for propensity score estimation.
- \code{\link[MatchThem]{MatchThem}} package for matching within imputed datasets.
}
